import Autosuggest from 'react-autosuggest'
import axios from 'axios'
import classNames from 'classnames'
import React, { PropTypes } from 'react'

import styles from './DevicePicker.css'

const propTypes = {
  meshbluConfig: PropTypes.object.isRequired,
  className: PropTypes.string
}

class DevicePicker extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      devices: [],
      error: null,
      value: '',
    }

    this.onChange = this.onChange.bind(this);
    this.renderSuggestion = this.renderSuggestion.bind(this);
    this.getSuggestionValue = this.getSuggestionValue.bind(this);
  }

  componentWillMount() {
    if(!this.props.meshbluConfig) {
      this.setState({error: new Error('No meshbluConfig') })
    }
    else {
      const { meshbluConfig }       = this.props
      const { uuid, token, server } = meshbluConfig

      if(!server) {
        this.setState({ error: new Error('No server specified')})
      }
      if(!uuid || !token) {
        this.setState({ error: new Error('No uuid or token')})
      }

      const meshbluRequest = axios.create({
        baseURL: 'https://' + server,
        headers: {
          'meshblu_auth_uuid': uuid,
          'meshblu_auth_token': token
        }
      })

      meshbluRequest.get('/mydevices')
        .then(response => this.setState({devices: response.data.devices}))
        .catch(error => this.setState({ error: new Error(error.statusText) }))
    }
  }

  onChange(event, { newValue }) {
    this.setState({ value: newValue })
  }

  renderSuggestion(suggestion) {
    return <span>{suggestion.name}</span>
  }

  getSuggestionValue(suggestion) {
    return suggestion.name
  }

  render() {
    const { error, value, devices } = this.state
    const inputProps = {
      placeholder: 'Enter a device name',
      value,
      onChange: this.onChange
    };

    if (error) return <span>Error: { error.message }</span>

    return (
      <Autosuggest
        suggestions={devices}
        getSuggestionValue={this.getSuggestionValue}
        renderSuggestion={this.renderSuggestion}
        inputProps={inputProps}
      />
    )
  }
}

DevicePicker.propTypes = propTypes;

export default DevicePicker
