import chai, { expect } from 'chai';
import chaiEnzyme from 'chai-enzyme';
import React from 'react';
import sinon from 'sinon';
import { mount, shallow } from 'enzyme';

import DevicePicker from './DevicePicker';

chai.use(chaiEnzyme());

describe('<DevicePicker />', () => {

  it('should render an error message if state has an error property', () => {
    const sut = shallow(<DevicePicker />)
    sut.setState({ error: new Error('BANG!') })
    expect(sut).to.contain('BANG!')
  })

  it('should render an input if state has no errors', () => {
    const meshblu = {
      'uuid': 'magic-uuid',
      'token': 'magic-token',
      'server': 'meshblu.octoblu.com'
    }
    const sut = shallow(<DevicePicker meshbluConfig={meshblu}/>)
    expect(sut).to.have.className('MeshbluDevicePicker')
  })

  describe('When meshbluConfig prop is not passed in', () => {
    it('should update the error state appropriately', () => {
      const sut = shallow(<DevicePicker />)
      expect(sut.state('error').message).to.equal('No meshbluConfig')
    })
  })

  describe('When meshbluConfig prop is passed in', () => {

    describe('When meshbluConfig does not contain a server', () => {
      it('should update the error state appropriately', () => {
        const meshblu = {
          'uuid': 'magic-uuid',
          'token': 'magic-token'
        }
        const sut = mount(<DevicePicker meshbluConfig={meshblu} />)
        expect(sut.state('error').message).to.equal('No server specified')
      })
    })

    describe('When meshbluConfig does not contain a uuid/token', () => {
      it('should update the error state appropriately', () => {
        const meshblu = {
          'server': 'meshblu.octoblu.com'
        }
        const sut = mount(<DevicePicker meshbluConfig={meshblu} />)
        expect(sut.state('error').message).to.equal('No uuid or token')
      })
    })
  })
})
